@@ -70,7 +70,7 @@ bool WebSeedsModel::update()
         }
 
         if (changed) {
-            dataChanged(createIndex(i, 1), createIndex(i, 3));
+            Q_EMIT dataChanged(createIndex(i, 1), createIndex(i, 3));
             ret = true;
         }
     }
@@ -174,3 +174,5 @@ bool WebSeedsModel::setData(const QModelIndex &index, const QVariant &value, int
     return true;
 }
 }
+
+#include "moc_webseedsmodel.cpp"
